@@ -31,7 +31,11 @@ const QString KBlacklistFile = "/root/.fapman/black.list";
 const QString KOwnRepoFile = "/root/.fapman/repos.list";
 const QString KOwnRepoNamesFile = "/root/.fapman/repos.names";
 
-const QString KHamRepoListFile = "/etc/apt/sources.list.d/hildon-application-manager.list";
+#ifdef Q_WS_MAEMO_5
+	const QString KHamRepoListFile = "/etc/apt/sources.list.d/hildon-application-manager.list";
+#else
+	const QString KHamRepoListFile = "/etc/apt/sources.list";
+#endif
 
 const QString KLastUpdateFile = "/opt/fapman-cache/lastupdate";
 const QString KDateCacheFile = "/opt/fapman-cache/dates.cache";
@@ -65,24 +69,24 @@ public:
 						 ModeAptGetSimulate, ModeAptGetInstall, ModeAptGetClean };
 	enum multiLine { MultiLineNone, MultiLineDesc, MultiLineIcon, MultiLineUpgradeDesc };
 
-	AAptInterface(QObject* parent);
-	~AAptInterface();
+	explicit AAptInterface(QObject* parent);
+	virtual ~AAptInterface();
 	void setSettings(Settings* s_) { iSettings = s_; }
 
 	void addQueuedOperation(interfaceMode mode_);
 	bool run(dimmer* uiDimmer);
 	void setProcessPackages(QStringList pkgs) { iProcessPackages=pkgs; iProcessPackagesOrig=pkgs; }
-	QStringList processPackages() { return iProcessPackages; }
-	QStringList processPackageVersions() { return iProcessPackageVersions; }
+	QStringList processPackages() const { return iProcessPackages; }
+	QStringList processPackageVersions() const { return iProcessPackageVersions; }
 
-	bool running();
+	bool running() const;
 	bool cancel();
 
-	int numSelectedPackages() { return iNumSelectedPackages; }
+	int numSelectedPackages() const { return iNumSelectedPackages; }
 	void setNumSelectedPackages(int p_) { iNumSelectedPackages=p_; }
 
-	QHash<QString, Package*>* packagesAvailable() { return &iPackagesAvailable; }
-	QHash<QString, Package*>* packagesInstalled() { return &iPackagesInstalled; }
+	const QHash<QString, Package*>* packagesAvailable() { return &iPackagesAvailable; }
+	const QHash<QString, Package*>* packagesInstalled() { return &iPackagesInstalled; }
 	QList<Repository*>* repositories() { return  &iRepositories; }
 
 	QByteArray readLogFile();
@@ -104,6 +108,9 @@ public:
 	QDateTime lastDpkgUpdate() { return iLastDpkgUpdate; }
 
 private:
+	AAptInterface(const AAptInterface& old);
+	AAptInterface operator= (const AAptInterface& old);
+
 	void runNext();
 	void cleanAfterRunEach();
 	void cleanAfterRunAll();
