@@ -32,9 +32,11 @@ class FilterSelect : public QDialog
 
 public:
 	explicit FilterSelect(QString title, QWidget *parent = 0);
-    ~FilterSelect();
+	virtual ~FilterSelect();
+
 	void setList(QStringList labels, int selected);
 	int selection();
+	/*
 #ifdef Q_WS_MAEMO_5		// workaround for buggy Qt autorotation
 	int exec() {
 		QRect r = dynamic_cast<QWidget*>(this->parent())->rect();
@@ -45,11 +47,15 @@ public:
 		return e;
 	}
 #endif
+	*/
 
 protected:
     void changeEvent(QEvent *e);
 
 private:
+	FilterSelect(const FilterSelect& old);
+	FilterSelect operator= (const FilterSelect& old);
+
     Ui::FilterSelect *ui;
 
 };
