@@ -32,7 +32,9 @@ class Help : public QDialog
 
 public:
     explicit Help(QWidget *parent = 0);
-    ~Help();
+	virtual ~Help();
+
+	/*
 #ifdef Q_WS_MAEMO_5		// workaround for buggy Qt autorotation
 	int exec() {
 		QRect r = dynamic_cast<QWidget*>(this->parent())->rect();
@@ -43,11 +45,15 @@ public:
 		return e;
 	}
 #endif
+	*/
 
 protected:
     void changeEvent(QEvent *e);
 
 private:
+	Help(const Help& old);
+	Help operator= (const Help& old);
+
     Ui::Help *ui;
 };
 
