@@ -23,7 +23,10 @@
 #include "mainwindow.h"
 #include "confirmdialog.h"
 
-#include <unistd.h>
+extern "C"
+{
+	#include <unistd.h>
+}
 
 bool EnableDebugOutput = false;
 
@@ -48,12 +51,7 @@ int main(int argc, char *argv[])
 	}
 
 	MainWindow w;
-
-#if defined(Q_WS_S60)
-    w.showMaximized();
-#else
     w.show();
-#endif
 
 	uid_t userUID = getuid();
 	if( userUID != 0 ) {
