@@ -18,8 +18,11 @@
 */
 
 #ifdef MYDEF_GTK_EXISTS
-#include <gdk/gdk.h>
-#include <gtk/gtk.h>
+extern "C"
+{
+	#include <gdk/gdk.h>
+	#include <gtk/gtk.h>
+}
 #endif
 
 #include <QtCore>
@@ -33,7 +36,10 @@
 #include <QtMaemo5>
 #endif
 
-#include <sys/vfs.h>
+extern "C"
+{
+	#include <sys/vfs.h>
+}
 
 #include "mainwindow.h"
 #include "version.h"
@@ -76,12 +82,12 @@ MainWindow::MainWindow(QWidget *parent) :
 									   iSettings->qsettings()->value("search_desclong",false).toBool() );
 
 #ifdef Q_WS_MAEMO_5
-	this->setAttribute(Qt::WA_Maemo5StackedWindow);
 	if( !iSettings->qsettings()->value("disable_autorotation",false).toBool() ) {
 		this->setAttribute(Qt::WA_Maemo5AutoOrientation);
 	} else {
 		this->setAttribute(Qt::WA_Maemo5LandscapeOrientation);
 	}
+	this->setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
 
 	iDimmer = new dimmer(this);
@@ -132,24 +138,17 @@ MainWindow::MainWindow(QWidget *parent) :
 	}
 
 
-	/*
-	// does not work
-
-	QDBusConnection conn = QDBusConnection::connectToBus(QDBusConnection::SystemBus, "faster_application_manager");
-
-	QString service = "com.nokia.icd";
-	QString path = "/com/nokia/icd";
-	QString method = "connect";
-
-	QDBusInterface net(service, path, service, conn, this);
-	net.call(method,"[ANY]",0);
-	*/
-
 	iMediaObject = new Phonon::MediaObject(this);
 	Phonon::AudioOutput* aout = new Phonon::AudioOutput(Phonon::NotificationCategory, this);
 	Phonon::createPath(iMediaObject, aout);
 
 	showFreeSpace();
+
+	iNetworkConfigurationManager = new QNetworkConfigurationManager(this);
+	iNetworkSession = new QNetworkSession(iNetworkConfigurationManager->defaultConfiguration(),this);
+
+	show();
+	rescaleMenuView();
 }
 
 MainWindow::~MainWindow()
@@ -157,13 +156,33 @@ MainWindow::~MainWindow()
 	// save "need repo refresh" status
 	iSettings->qsettings()->setValue("need_repo_refresh", iAptInterface->needRepoRefresh());
 
-	delete iWinPackageView;
-	delete iWinRepoView;
-	delete iAptInterface;
-	delete iDpkgInterface;
-	delete iDimmer;
-	delete iSettings;
-    delete ui;
+	if( iNetworkSession && iNetworkSession->isOpen() ) {
+		iNetworkSession->close();
+	}
+	// iNetworkSession automatically deleted by parent
+
+	delete iWinPackageView; iWinPackageView=0;
+	delete iWinRepoView; iWinRepoView=0;
+	delete iAptInterface; iAptInterface=0;
+	delete iDpkgInterface; iDpkgInterface=0;
+	delete iDimmer; iDimmer=0;
+	delete iSettings; iSettings=0;
+	delete ui; ui=0;
+	//iMediaObject and aout automatically deleted by their parent
+}
+
+void MainWindow::openNetworkConnection()
+{
+	if( iNetworkSession->isOpen() )
+		return;
+
+	iNetworkSession->open();
+	if( !iNetworkSession->waitForOpened(20000) )
+	{
+		ConfirmDialog d(false, this);
+		d.setText("Network error","Unable to open a network connection");
+		d.exec();
+	}
 }
 
 void MainWindow::changeEvent(QEvent *e)
@@ -187,6 +206,8 @@ void MainWindow::on_btnUpdate_clicked()
 {	
 	// update catalogs
 
+	openNetworkConnection();
+
 	busyDialog(true, tr("Operation in progress"), tr("Updating catalogs"));
 
 	iAptInterface->addQueuedOperation(AAptInterface::ModeAptGetUpdate);
@@ -233,6 +254,8 @@ void MainWindow::on_btnListInstallable_clicked()
 {
 	//install
 
+	openNetworkConnection();
+
 	int listupd = -1;
 	int dpkgupd = -1;
 	if( iAptInterface->lastListUpdate() < QDateTime::currentDateTime().addSecs(-KListExpireTime) )
@@ -260,6 +283,8 @@ void MainWindow::on_btnUpgrade_clicked()
 {
 	// upgrade
 
+	openNetworkConnection();
+
 	int listupd = -1;
 	int dpkgupd = -1;
 	if( iAptInterface->lastListUpdate() < QDateTime::currentDateTime().addSecs(-KListExpireTime) )
@@ -413,7 +438,7 @@ void MainWindow::operationQueueFinished(QList<AAptInterface::interfaceMode> last
 					installing_blacklisted = true;
 				}
 #ifdef Q_WS_MAEMO_5
-				if( pkg && pkg->maemoDisplayName()=="Maemo 5" ) {
+				if( pkg && pkg->maemoDisplayName()=="Maemo 5" ) {	// unreliable?
 					warn_system_package_install = true;
 				}
 #endif
@@ -648,10 +673,30 @@ void MainWindow::on_actionLoad_file_triggered()
 	}
 }
 
+void MainWindow::resizeEvent(QResizeEvent* event)
+{
+	rescaleMenuView();
+
+	if( iDimmer ) {
+		iDimmer->resize( this->size() );
+	}
+
+	QMainWindow::resizeEvent(event);
+}
+
+void MainWindow::rescaleMenuView()
+{
+	QRect sg = ui->listWidget->rect();
+
+	if( sg.width() > sg.height() ) {
+		ui->listWidget->setGridSize( QSize((sg.width()-12)/5, (sg.height()-12)/2) );
+	} else {
+		ui->listWidget->setGridSize( QSize((sg.width()-12)/3, (sg.height()-12)/3) );
+	}
+}
+
 void MainWindow::orientationChanged()
 {
-	//ui->centralWidget->adjustSize();
-	//ui->listWidget->adjustSize();
 }
 
 
@@ -663,10 +708,10 @@ void MainWindow::showFreeSpace()
 	struct statfs opt_stat;
 	statfs("/",&root_stat);
 	statfs("/opt",&opt_stat);
-	quint64 free_root = root_stat.f_bavail * root_stat.f_bsize / 1024;
-	quint64 free_opt = opt_stat.f_bavail * opt_stat.f_bsize / 1024;
-	quint64 total_root = root_stat.f_blocks * root_stat.f_bsize / 1024;
-	quint64 total_opt = opt_stat.f_blocks * opt_stat.f_bsize / 1024;
+	quint64 free_root = static_cast<quint64>(root_stat.f_bavail) * static_cast<quint64>(root_stat.f_bsize) / 1024;
+	quint64 free_opt = static_cast<quint64>(opt_stat.f_bavail) * static_cast<quint64>(opt_stat.f_bsize) / 1024;
+	quint64 total_root = static_cast<quint64>(root_stat.f_blocks) * static_cast<quint64>(root_stat.f_bsize) / 1024;
+	quint64 total_opt = static_cast<quint64>(opt_stat.f_blocks) * static_cast<quint64>(opt_stat.f_bsize) / 1024;
 	qDebug() << "rootfs" << free_root << "/" << total_root << "kB free";
 	qDebug() << "opt fs" << free_opt << "/" << total_opt << "kB free";
 
@@ -700,19 +745,21 @@ void MainWindow::showFreeSpace()
 
 void MainWindow::on_listWidget_itemClicked(QListWidgetItem* item)
 {
-	if( item->text() == "Manage repositories" ) {
+	qDebug() << "main menu:" << item->statusTip();
+
+	if( item->statusTip() == "manage_repos" ) {
 		on_btnRepos_clicked();
 	}
-	else if( item->text() == "Update catalogs" ) {
+	else if( item->statusTip() == "update_catalogs" ) {
 		on_btnUpdate_clicked();
 	}
-	else if( item->text() == "Install applications" ) {
+	else if( item->statusTip() == "install_apps" ) {
 		on_btnListInstallable_clicked();
 	}
-	else if( item->text() == "Remove applications" ) {
+	else if( item->statusTip() == "remove_apps" ) {
 		on_btnListInstalled_clicked();
 	}
-	else if( item->text() == "Upgrade applications" ) {
+	else if( item->statusTip() == "upgrade_apps" ) {
 		on_btnUpgrade_clicked();
 	}
 	else {
