@@ -543,7 +543,7 @@ void PackageSelector::queryChangelog()
 
 	if( !iNetworkAccessManager ) {
 		iNetworkAccessManager = new QNetworkAccessManager(this);
-		connect(iNetworkAccessManager,SIGNAL(finished(QReply*)),this,SLOT(changelogFetchNetworkReply(QReply*)));
+        connect(iNetworkAccessManager,SIGNAL(finished(QNetworkReply*)),this,SLOT(changelogFetchNetworkReply(QNetworkReply*)));
 
 		if( iSettings->qsettings()->value("use_proxies").toBool() && !iSettings->qsettings()->value("http_proxy").toString().isEmpty() )
 		{
