@@ -30,13 +30,14 @@ namespace Ui {
 
 class AAptInterface;
 class Settings;
+class MainWindow;
 
 class PackageSelector : public QDialog
 {
     Q_OBJECT
 
 public:
-	explicit PackageSelector(Package* pkg, AAptInterface* apt, Settings* set, QWidget *parent);
+	explicit PackageSelector(Package* pkg, AAptInterface* apt, Settings* set, MainWindow* mw, QWidget *parent);
 	virtual ~PackageSelector();
 
 	/*
@@ -71,6 +72,7 @@ private:
 	AAptInterface* iAptInterface;
 	Settings* iSettings;
 	QNetworkAccessManager* iNetworkAccessManager;
+	MainWindow* iMainWindow;
 	bool iChangelogFetched;
 	bool iFetchInProgress;
 	QString iChangelog;
