@@ -649,7 +649,7 @@ void PackageView::on_listWidget_itemClicked(QListWidgetItem* item)
 	if( upg_pkg )
 		bl_u = upg_pkg->isBlacklisted();
 
-	PackageSelector s(pkg, iAptInterface, iSettings, this);
+	PackageSelector s(pkg, iAptInterface, iSettings, iMainWindow, this);
 	s.exec();
 	Package::operation op = s.selectedOperation();
 
