@@ -103,22 +103,12 @@ public:
 
 	void show() {
 		if( !isVisible() ) {
-			/*
-			QRect r = dynamic_cast<QMainWindow*>(this->parent())->rect();
-			if(r.width() < r.height()) {
-				this->setAttribute(Qt::WA_Maemo5PortraitOrientation);
-			}
-			else {
-				if( dynamic_cast<QMainWindow*>(this->parent())->testAttribute( Qt::WA_Maemo5AutoOrientation ) ) {
-					this->setAttribute( Qt::WA_Maemo5AutoOrientation );
-				} else {
-					this->setAttribute( Qt::WA_Maemo5LandscapeOrientation );
-				}
-				this->setAttribute(Qt::WA_Maemo5StackedWindow);
-				this->setWindowFlags( Qt::Window );
-			}
-			*/
 #ifdef Q_WS_MAEMO_5
+            if(	dynamic_cast<QMainWindow*>(this->parent())->testAttribute( Qt::WA_Maemo5AutoOrientation ) ) {
+                this->setAttribute( Qt::WA_Maemo5AutoOrientation );
+            } else {
+                this->setAttribute( Qt::WA_Maemo5LandscapeOrientation );
+            }
 			this->setAttribute(Qt::WA_Maemo5StackedWindow);
 			this->setWindowFlags( Qt::Window );
 #endif
