@@ -22,12 +22,15 @@
 #include "package.h"
 #include "aaptinterface.h"
 
-Repository::Repository()
+Repository::Repository(): iEnabled(false)
 {
-	iEnabled = false;
 }
 
-QString Repository::toString()
+Repository::~Repository()
+{
+}
+
+QString Repository::toString() const
 {
 	QString str;
 	if( iEnabled )
@@ -42,7 +45,7 @@ QString Repository::toString()
 	return( str.trimmed() );
 }
 
-QStringList Repository::toListFileNames()
+QStringList Repository::toListFileNames() const
 {
 	QStringList names;
 
