@@ -32,7 +32,7 @@ class SearchOptions : public QDialog
 
 public:
     explicit SearchOptions(QWidget *parent = 0);
-    ~SearchOptions();
+	virtual ~SearchOptions();
 
 	void setSelections(bool pkgname, bool dispname, bool dshort, bool dlong);
 	bool searchPkgName();
@@ -44,6 +44,9 @@ protected:
     void changeEvent(QEvent *e);
 
 private:
+	SearchOptions(const SearchOptions& old);
+	SearchOptions operator= (const SearchOptions& old);
+
     Ui::SearchOptions *ui;
 };
 
