@@ -36,11 +36,12 @@ class Settings : public QDialog
 
 public:
     explicit Settings(QWidget *parent = 0);
-    ~Settings();
+	virtual ~Settings();
 	void openWin();
 	void setAptInterface(AAptInterface* apt) { iAptInterface=apt; }
 	void setPackageView(PackageView* v_) { iPackageView=v_; }
 
+	/*
 #ifdef Q_WS_MAEMO_5		// workaround for buggy Qt autorotation
 	void open() {
 		QRect r = dynamic_cast<QWidget*>(this->parent())->rect();
@@ -55,6 +56,7 @@ public:
 		QDialog::open();
 	}
 #endif
+	*/
 
 	QSettings* qsettings() { return iQSettings; }
 
@@ -64,6 +66,9 @@ protected:
     void changeEvent(QEvent *e);
 
 private:
+	Settings(const Settings& old);
+	Settings operator= (const Settings& old);
+
     Ui::Settings *ui;
 	QSettings* iQSettings;
 	AAptInterface* iAptInterface;
@@ -71,8 +76,8 @@ private:
 
 private slots:
 	void on_pushButton_searchOptions_clicked();
- void on_pushButton_picksound_clicked();
- void on_btn_OK_clicked();
+	void on_pushButton_picksound_clicked();
+	void on_btn_OK_clicked();
 };
 
 #endif // SETTINGS_H
